## Windows LTSC Microsoft Store 最新版下载安装脚本
- LTSC2021
- LTSC2019

测试通过

## 🔽下载软件包

- [Github官方](https://github.com/Goojoe/LTSC-ADD-Microsoft-Store/archive/refs/heads/master.zip)

✨镜像地址(国内推荐)

- [FastGit](https://archive.fastgit.org/Goojoe/LTSC-ADD-Microsoft-Store/archive/refs/heads/master.zip)
- [ghproxy](https://ghproxy.com/https://github.com/Goojoe/LTSC-ADD-Microsoft-Store/archive/refs/heads/master.zip)

## 安装Microsoft商店

### 1.安装Python

- [镜像下载](https://mirror.bjtu.edu.cn/python/3.10.8/)
- [官方下载](https://www.python.org/downloads/)

安装时需勾选`Add Python 3.10 to PATH`

<img src="https://i0.hdslb.com/bfs/album/470bd8fff34b02f858814bf43afe4542c51d3127.png" referrerpolicy="no-referrer">

### 2.安装依赖

```
# 更换镜像
pip config set global.index-url https://mirror.sjtu.edu.cn/pypi/web/simple/
# 安装依赖
pip install requests lxml pyperclip
```

### 3.启动脚本

`shift`+`鼠标右键`打开powershell

```
python GetStore.py
```

---

## 软件来源

> 所有软件来自https://store.rg-adguard.net/
>
> Url(Link) `https://www.microsoft.com/store/productId/9WZDNCRFJBMP` RP

## 关于转载

版权属于`Microsoft`,禁止商用

⚠️不允许转载后的内容需要”回复“、”登录“、”关注公众号“、”积分购买“以及其他任何不能直接下载的形式展现
